//+------------------------------------------------------------------+
//|                                                       GbpChf.mq5 |
//|                        Copyright 2018, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2018, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
#include <Trade\PositionInfo.mqh>
#include <Trade\Trade.mqh>
#include <Trade\SymbolInfo.mqh>  
CPositionInfo  m_position;                   // trade position object
CTrade         m_trade;                      // trading object
CSymbolInfo    m_symbol;                     // symbol info object
//--- input parameters
input string            Inp_DeM_1_symbol     = "GBPUSD";    // DeM 1: symbol name 
input ENUM_TIMEFRAMES   Inp_DeM_1_period     = PERIOD_H4;   // DeM 1: period 
input int               Inp_DeM_1_ma_period  = 24;          // DeM 1: averaging period 
input string            Inp_DeM_2_symbol     = "USDCHF";    // DeM 2: symbol name 
input ENUM_TIMEFRAMES   Inp_DeM_2_period     = PERIOD_H4;   // DeM 2: period 
input int               Inp_DeM_2_ma_period  = 24;          // DeM 2: averaging period 
//---
input ulong m_magic=126840;               // magic number
//---
ulong m_slippage=10;                      // slippage

int   handle_iDeMarker_1;                 // variable for storing the handle of the iDeMarker indicator 
int   handle_iDeMarker_2;                 // variable for storing the handle of the iDeMarker indicator 
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
   if(!m_symbol.Name(Symbol())) // sets symbol name
      return(INIT_FAILED);
   RefreshRates();
//---
   m_trade.SetExpertMagicNumber(m_magic);
   m_trade.SetMarginMode();
   m_trade.SetTypeFillingBySymbol(m_symbol.Name());
   m_trade.SetDeviationInPoints(m_slippage);
//--- create handle of the indicator iDeMarker
   handle_iDeMarker_1=iDeMarker(Inp_DeM_1_symbol,Inp_DeM_1_period,Inp_DeM_1_ma_period);
//--- if the handle is not created 
   if(handle_iDeMarker_1==INVALID_HANDLE)
     {
      //--- tell about the failure and output the error code 
      PrintFormat("Failed to create handle of the iDeMarker indicator for the symbol %s/%s, error code %d",
                  Inp_DeM_1_symbol,
                  EnumToString(Inp_DeM_1_period),
                  GetLastError());
      //--- the indicator is stopped early 
      return(INIT_FAILED);
     }
//--- create handle of the indicator iDeMarker
   handle_iDeMarker_2=iDeMarker(Inp_DeM_2_symbol,Inp_DeM_2_period,Inp_DeM_2_ma_period);
//--- if the handle is not created 
   if(handle_iDeMarker_2==INVALID_HANDLE)
     {
      //--- tell about the failure and output the error code 
      PrintFormat("Failed to create handle of the iDeMarker indicator for the symbol %s/%s, error code %d",
                  Inp_DeM_2_symbol,
                  EnumToString(Inp_DeM_2_period),
                  GetLastError());
      //--- the indicator is stopped early 
      return(INIT_FAILED);
     }

//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   Comment("");
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//--- we work only at the time of the birth of new bar
   static datetime PrevBars=0;
   datetime time_0=iTime(m_symbol.Name(),Period(),0);
   if(time_0==PrevBars)
      return;
   PrevBars=time_0;
   if(!RefreshRates())
     {
      PrevBars=0;
      return;
     }
   double array_dem_1[];
   double array_dem_2[];
   int buffer   = 0;
   int start_pos= 0;
   int count    = 1;
   if(!iGetArray(handle_iDeMarker_1,buffer,start_pos,count,array_dem_1) || 
      !iGetArray(handle_iDeMarker_2,buffer,start_pos,count,array_dem_2))
      return;
   string text="DeM 1 ("+Inp_DeM_1_symbol+" #"+IntegerToString(start_pos)+": "+DoubleToString(array_dem_1[0],8)+"\n"+
               "DeM 2 ("+Inp_DeM_2_symbol+" #"+IntegerToString(start_pos)+": "+DoubleToString(array_dem_2[0],8);
   Comment(text);
  }
//+------------------------------------------------------------------+
//| TradeTransaction function                                        |
//+------------------------------------------------------------------+
void OnTradeTransaction(const MqlTradeTransaction &trans,
                        const MqlTradeRequest &request,
                        const MqlTradeResult &result)
  {
//---

  }
//+------------------------------------------------------------------+
//| Refreshes the symbol quotes data                                 |
//+------------------------------------------------------------------+
bool RefreshRates(void)
  {
//--- refresh rates
   if(!m_symbol.RefreshRates())
     {
      Print("RefreshRates error");
      return(false);
     }
//--- protection against the return value of "zero"
   if(m_symbol.Ask()==0 || m_symbol.Bid()==0)
      return(false);
//---
   return(true);
  }
//+------------------------------------------------------------------+
//| Get value of buffers                                             |
//+------------------------------------------------------------------+
double iGetArray(const int handle,const int buffer,const int start_pos,const int count,double &arr_buffer[])
  {
   bool result=true;
   if(!ArrayIsDynamic(arr_buffer))
     {
      Print("This a no dynamic array!");
      return(false);
     }
   ArrayFree(arr_buffer);
//--- reset error code 
   ResetLastError();
//--- fill a part of the iBands array with values from the indicator buffer
   int copied=CopyBuffer(handle,buffer,start_pos,count,arr_buffer);
   if(copied!=count)
     {
      //--- if the copying fails, tell the error code 
      PrintFormat("Failed to copy data from the indicator, error code %d",GetLastError());
      //--- quit with zero result - it means that the indicator is considered as not calculated 
      return(false);
     }
   return(result);
  }
//+------------------------------------------------------------------+
